satscan(prmlocation, prmfilename, sslocation = "c:/progra~2/satscan", ssbatchfilename = "SaTScanBatch", cleanup = TRUE, verbose = FALSE)sp
package. It contains the ESRI shapefile(s) SaTScan makes. This is made only if the rgdal
package is available.ss.options function or not.
If not, or if the matchout = FALSE parameter was set in ss.options, then the
return object will include the main text output from SaTScan only you manually set the
ResultsFile SaTScan parameter to have the same name as the parameter file.
ss.options, write.ss.prm
## Not run:
# ## Please see vignette("rsatscan"); example() code doesn't make sense since
# ## all examples rely on calls to SaTScan in the OS.
# ## End(Not run)
Run the code above in your browser using DataLab