if (FALSE) {
# Append second data file to the Multiple Data Sets section of the parameter list
ss.options.extra(invals=list(CaseFile2="NYCfever.cas"), section="Multiple Data Sets")
print(ss.options()[67:70])
# Specify columns in the case input file to be included in the line list output file
ss.options.extra(invals=list('CaseFile-SourceLinelistFieldMap'=strwrap(
"0:0:\"IndividualID\",
4:1:\"DescriptiveLongitude\",
2:2:\"DescriptiveLatitude\",
3:3:\"AGE\",
1:3:\"GENDER\"")),
section="Input")
# Can also append to the end of the parameter file by not specifying a section.
# This is useful for adding comments.
# Note that the input value can be specified as a character string instead of a list
# just like 'ss.options()'
ss.options.extra(invals=";This is the end of the parameter list.")
tail(ss.options(), 3)
}
Run the code above in your browser using DataLab